import { Browser, BrowserConnectOptions, BrowserLaunchArgumentOptions, LaunchOptions as PPTLaunchOptions, Page, Product } from 'puppeteer';
import * as Config from 'lighthouse/types/config';
import { UserFlow } from 'lighthouse/lighthouse-core/fraggle-rock/user-flow';
import { SharedFlagsSettings } from 'lighthouse/types/lhr/settings';
import { PickOne } from '../../../../core/utils/types';
import FlowResult from 'lighthouse/types/lhr/flow';
export declare type UserFlowContext = {
    browser: Browser;
    page: Page;
    flow: UserFlow;
    collectOptions: {
        url: string;
    };
};
export declare type StepOptions = {
    stepName: string;
} & {
    config?: Config.default.Json;
};
export declare type UserFlowInteractionsFn = (context: UserFlowContext) => Promise<void>;
export declare type UserFlowOptions = {
    name: string;
} & {
    config?: Config.default.Json;
};
export declare type LaunchOptions = PPTLaunchOptions & BrowserLaunchArgumentOptions & BrowserConnectOptions & {
    product?: Product;
    extraPrefsFirefox?: Record<string, unknown>;
};
/**
 * budgets: path to budgets file
 */
declare type UserFlowRcOptions = {
    config: {
        settings: {
            budgets: string | SharedFlagsSettings['budgets'];
        };
    };
} & UserFlowOptions;
export declare type UserFlowProvider = {
    flowOptions: UserFlowOptions | UserFlowRcOptions;
    interactions: UserFlowInteractionsFn;
    launchOptions?: LaunchOptions;
};
export declare type ReducedReport = {
    name: string;
    steps: ReducedFlowStep[];
};
declare type UfrSlice = PickOne<FlowResult>;
declare type LhrSlice = PickOne<FlowResult.Step['lhr']>;
/**
 * Plucks key value from oroginal LH report
 * @example
 *
 * const t: GatherModeSlice = {gatherMode: 'navigation'};
 * const f1: GatherModeSlice = {gatherddMode: 'navigation'};
 * const f2: GatherModeSlice = {gatherMode: 'navigationddddd'};
 */
declare type LhrGatherModeSlice = LhrSlice & {
    gatherMode: FlowResult.Step['lhr']['gatherMode'];
};
declare type UfrNameSlice = UfrSlice & {
    name: string;
};
/**
 * This type is the result of `calculateCategoryFraction` https://github.com/GoogleChrome/lighthouse/blob/master/core/util.cjs#L540.
 * As there is no typing present ATM we maintain our own.
 */
export declare type FractionResults = {
    numPassed: number;
    numPassableAudits: number;
    numInformative: number;
    totalWeight: number;
};
export declare type ReducedFlowStepResult = Record<string, number | FractionResults>;
export declare type ReducedFlowStep = UfrNameSlice & LhrGatherModeSlice & {
    results: ReducedFlowStepResult;
};
export {};
